import React, { Component } from "react";
import { Link } from "react-router-dom";
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';

import { signInRequest } from './../../actions/auth/signIn'
import { signUpRequest } from './../../actions/auth/signUp'

import * as routes from './../../constants/routes'

import { auth } from '../../firebase_config'

class Header extends Component {
    
    render() {
        const { isFetching, error, user } = this.props.auth;
        const { signInRequest } = this.props; 

        return (
            <header className="header">
                {
                    !user
                        ? <p>You need to sign in first...</p>
                        : (
                            <nav className="header__nav">
                                <Link className="header__nav-item" to="/favorites">
                                    Favorites
                                </Link>
                                <Link className="header__nav-item" to="/passed">
                                    Passed
                                </Link>
                                <Link className="header__nav-item" to="/results">
                                    Results
                                </Link>
                            </nav>
                        )
                }

                <div className="header__input_s">
                    <input />
                    <button type="submit">Click</button>
                </div>
                <div>
                    <Link to="/profile">
                        <img className="header__profile" src="https://bit.ly/2LuGzwz" />
                    </Link>
                </div>
                {
                    user && user.displayName
                        ? <p>{user.displayName}</p>
                        : <Link to={routes.SIGN_IN}><button onClick={null & signInRequest}>Sign in</button></Link>
                }
            </header>
        )
    }
}

const
    mapStateToProps = state => ({
        auth: {
            ...state.signIn
        }
    }),
    mapDispatchToProps = dispatch => bindActionCreators({
        signInRequest,
        signUpRequest
    }, dispatch);

export default connect(mapStateToProps, mapDispatchToProps)(Header)